FlowPopupAnimator class

A CurvedAnimation preset for the flow_box_popup morph transition.

Wraps a parent AnimationController with configurable forward and reverse easing curves, defaulting to Cubic(1.0, 0.155, 0.155, 1.0) — a subtle overshoot similar to easeOutBack for a snappy, modern feel.

Example:

final animator = FlowPopupAnimator(
  parent: controller,
  curve: Curves.easeInOutQuart,
  reverseCurve: Curves.easeOutCubic,
);
Inheritance

Constructors

FlowPopupAnimator({required AnimationController parent, Curve curve = const Cubic(1.0, 0.155, 0.155, 1.0), Curve reverseCurve = const Cubic(1.0, 0.155, 0.155, 1.0)})
Creates a FlowPopupAnimator.

Properties

curve Curve
The curve to use in the forward direction.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isAnimating bool
Whether this animation is running in either direction.
no setterinherited
isCompleted bool
Whether this animation is stopped at the end.
no setterinherited
isDismissed bool
Whether this animation is stopped at the beginning.
no setterinherited
isDisposed bool
True if this CurvedAnimation has been disposed.
getter/setter pairinherited
isForwardOrCompleted bool
Whether the current aim of the animation is toward completion.
no setterinherited
parent Animation<double>
The animation to which this animation applies a curve.
finalinherited
reverseCurve Curve?
The curve to use in the reverse direction.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status AnimationStatus
The current status of this animation.
no setterinherited
value double
The current value of the animation.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Calls the listener every time the value of the animation changes.
inherited
addStatusListener(AnimationStatusListener listener) → void
Calls listener every time the status of the animation changes.
inherited
dispose() → void
Cleans up any listeners added by this CurvedAnimation.
inherited
drive<U>(Animatable<U> child) Animation<U>
Chains a Tween (or CurveTween) to this Animation.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(VoidCallback listener) → void
Stop calling the listener every time the value of the animation changes.
inherited
removeStatusListener(AnimationStatusListener listener) → void
Stops calling the listener every time the status of the animation changes.
inherited
toString() String
A string representation of this object.
inherited
toStringDetails() String
Provides a string describing the status of this object, but not including information about the object itself.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited