flow_popup_overlay library

Classes

FlowPopupOverlay
A widget that handles the animated transition of a popup expanding from its source widget into an overlay with smooth interpolation between size, position, and decoration.