childPadding property
Inner padding applied to the child content during the morph transition.
Implementation
final EdgeInsetsGeometry childPadding;
Inner padding applied to the child content during the morph transition.
final EdgeInsetsGeometry childPadding;